/**
 * The contents of this file are subject to the OpenMRS Public License
 * Version 1.0 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://license.openmrs.org
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 *
 * Copyright (C) OpenMRS, LLC.  All Rights Reserved.
 */

package org.openmrs.module.kenyaemr.calculation.library.hiv.art;

import org.openmrs.Concept;
import org.openmrs.Obs;
import org.openmrs.calculation.patient.PatientCalculationContext;
import org.openmrs.calculation.result.CalculationResultMap;
import org.openmrs.calculation.result.SimpleResult;
import org.openmrs.module.kenyacore.calculation.AbstractPatientCalculation;
import org.openmrs.module.kenyacore.calculation.Calculations;
import org.openmrs.module.kenyaemr.Dictionary;
import org.openmrs.module.kenyaemr.calculation.EmrCalculationUtils;

import java.util.Collection;
import java.util.Date;
import java.util.Map;

/**
 * Calculates whether a patient is a transfer in date
 */
public class TransferInDateCalculation extends AbstractPatientCalculation {
	/**
	 * @see org.openmrs.calculation.patient.PatientCalculation#evaluate(java.util.Collection,
	 *      java.util.Map, org.openmrs.calculation.patient.PatientCalculationContext)
	 */
	@Override
	public CalculationResultMap evaluate(Collection<Integer> cohort, Map<String, Object> parameterValues,
										 PatientCalculationContext context) {

		Concept transferInDate = Dictionary.getConcept(Dictionary.TRANSFER_IN_DATE);
		Concept transferInStatus = Dictionary.getConcept(Dictionary.TRANSFER_IN);
		CalculationResultMap transferInStatusResults = Calculations.lastObs(transferInStatus,cohort,context);

		CalculationResultMap transferInDateResults = Calculations.lastObs(transferInDate, cohort, context);

		CalculationResultMap result = new CalculationResultMap();
		for (Integer ptId : cohort) {
			Date transferInDateValue = null;
			Date tDate = EmrCalculationUtils.datetimeObsResultForPatient(transferInDateResults, ptId);
			Obs statusObs = EmrCalculationUtils.obsResultForPatient(transferInStatusResults, ptId);
			if(tDate != null){
				transferInDateValue = tDate;
			}
			else if(statusObs != null && statusObs.getValueCoded().equals(Dictionary.getConcept(Dictionary.YES))) {
				transferInDateValue = statusObs.getObsDatetime();
			}

			result.put(ptId, new SimpleResult(transferInDateValue, this));

		}
		return result;
	}
}
